---
title: '[점검] 네이버페이 서비스 일시중단 (시스템점검)'
category: 공지사항
tags:
  - 네이버페이(결제형)
  - 네이버페이(주문형)
  - 공지사항
datetime: 2023-06-20T15:00:00.000Z
---

안녕하세요\~! 포트원 입니다.

아래와 같이  네이버페이에서 비상대응훈련 진행으로 \[네이버페이 전체 서비스가 일시적으로 중단 ] 될 예정인 점 참고하셔서 서비스 이용에 불편 없으시길 바랍니다.

■ 시스템 점검 시간 : 2023년 7월 8일(토) 02:00 \~ 06:00 (약 4시간)

■ 시스템 영향 범위 : 네이버페이 전체 서비스 및 주문 API, 문의 API 영역

■ 시스템 영향 내용 : 네이버페이 주문API / 문의 API 중단 및 네이버페이 전체 서비스 중단

서비스 이용에 불편을 드려 죄송합니다.

더욱 안정적인 서비스 제공으로 보답하는 네이버페이가 되겠습니다.

감사합니다.
